/*
 * calcclockset - a command line utility to set clock-related parameters
 * on a TI89 Titanium calculator over the USB link
 *
 * Copyright (C) 2010 Michael Jordan
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "ti_usb.h"
#include "ti_file.h"

int main(int argc, char *argv[]) {
	if(argc > 1) {
		string argument;
		argument.append(argv[1]);
		bool help = false;
		bool valid = false;
		if((argument == "-h") || (argument == "--help")) {
			valid = true;
			help = true;
		}
		if(!valid) help = true;
		if(help) {
			cout <<
					"\ncalcclockset is a utility to set the clock on a\n" <<
					"TI89 Titanium calculator over the USB link.\n\n" << flush;
			cout <<
					"It allows the user to choose whether to use the PC's system\n" <<
					"time or whether to enter the date and time values individually.\n" <<
					flush;
			cout <<
					"Keep in mind that this is, in fact, free software, developed\n" <<
					"independently and therefore comes with no warranty.\n" << flush;
			return EX_OK;
		}
	}
	cout << "Searching for calculator..." << flush;
	ti_usb calc;

	// Calling is_good() here verifies that there was a calculator located on
	// the USB bus and that we can in fact communicate with it.
	if(calc.is_good()) {
		cout << "found calculator\n";

		// Create an object of type date_time to hold our date/time values that
		// we wish to set on the calculator.
		ti_usb::date_time dt;

		// Have the user fill in the values.  Or enter 0 to retrieve the current
		// system time and set the calculator to that.
		cout << "Year (1997 - 2084, 0 to use system time):  ";
		cin >> dt.year;
		if(dt.year == 0) {
			cout << "Getting system time ";
			if(!calc.get_sys_time(&dt)) {
				cout << "failed\n";
				return -1;
			}
			cout << "succeeded\n";
		} else {
			cout << "Month (1 - 12):  ";
			cin >> dt.month;
			cout << "Day (1 - 31):  ";
			cin >> dt.day;
			cout << "Hour (0 - 23):  ";
			cin >> dt.hour;
			cout << "Minute (0 - 59):  ";
			cin >> dt.minute;
			cout << "Second (0 - 59):  ";
			cin >> dt.second;
		}
		cout << "Setting clock on the calculator ";
		if(!calc.set_clock(dt)) {
			cout << "failed";
			return -1;
		}
		cout << "succeeded\n";
		return 0;
	}
	cout << "\nNo calculator found on the USB bus\n";
	return -1;
}
